@@ -14,10 +14,6 @@
  * limitations under the License.
  */
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <stdint.h>
-#include <setjmp.h>
 #include <cmocka.h>
 
 #define UNIT_TESTING 1
