@@ -1,12 +1,14 @@
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
+#include "config.h"
+
 #include <cmocka.h>
+#include <cmocka_private.h>
 
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <fcntl.h>
 
 /**************************************
@@ -14,7 +16,7 @@
  **************************************/
 static void test_assert_return_code(void **state)
 {
-    struct stat sb;
+    struct stat sb = {0};
     int rc;
 
     (void)state; /* unused */
@@ -22,12 +24,15 @@ static void test_assert_return_code(void **state)
     rc = stat(".", &sb);
     assert_return_code(rc, 0);
 
+#ifndef _MSC_VER
     assert_true(S_ISDIR(sb.st_mode));
+#endif
 }
 
 int main(void) {
-    const UnitTest tests[] = {
-        unit_test(test_assert_return_code),
+    const struct CMUnitTest tests[] = {
+        cmocka_unit_test(test_assert_return_code),
     };
-    return run_tests(tests);
+
+    return cmocka_run_group_tests(tests, NULL, NULL);
 }
