@@ -1,7 +1,3 @@
-#include <stdarg.h>
-#include <stddef.h>
-#include <stdint.h>
-#include <setjmp.h>
 #include <cmocka.h>
 
 #include <stdlib.h>
@@ -29,6 +25,12 @@ static void malloc_setup_test(void **state)
 static void malloc_teardown_test(void **state)
 {
     *state = malloc(1);
+    if (*state == NULL) {
+        // do nothing, we're just checking this because otherwise GCC 11
+        // sometimes incorrectly throws a -Werror=maybe-uninitialized error
+        // This is fixed in GCC 12
+        assert_null(NULL);
+    }
     assert_non_null(*state);
 }
 
