@@ -14,19 +14,17 @@
  * limitations under the License.
  */
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <stdint.h>
-#include <setjmp.h>
 #include <cmocka.h>
 
 static void torture_string_equal(void **state)
 {
+    (void)state; /* unused */
     assert_string_equal("wurst", "wurst");
 }
 
 static void torture_string_not_equal(void **state)
 {
+    (void)state; /* unused */
     assert_string_not_equal("wurst", "brot");
 }
 
